==> blesta-5.8.0.zip: blesta/components/modules/connectreseller/language/en_us/connectreseller.php <==
<?php
/**
 * en_us language for the Connectreseller module.
 */
// Basics
$lang['Connectreseller.name'] = 'ConnectReseller';
$lang['Connectreseller.description'] = 'ConnectReseller is one of the largest Registrars that has created a of set completely private labeled programs for domainers.';
$lang['Connectreseller.module_row'] = 'Account';
$lang['Connectreseller.module_row_plural'] = 'Accounts';
$lang['Connectreseller.module_group'] = 'Account Group';


// Module management
$lang['Connectreseller.add_module_row'] = 'Add Account';
$lang['Connectreseller.add_module_group'] = 'Add Account Group';
$lang['Connectreseller.manage.module_rows_title'] = 'Accounts';

$lang['Connectreseller.manage.module_rows_heading.api_key'] = 'API Key';
$lang['Connectreseller.manage.module_rows_heading.options'] = 'Options';
$lang['Connectreseller.manage.module_rows.edit'] = 'Edit';
$lang['Connectreseller.manage.module_rows.delete'] = 'Delete';
$lang['Connectreseller.manage.module_rows.confirm_delete'] = 'Are you sure you want to delete this Account';

$lang['Connectreseller.manage.module_rows_no_results'] = 'There are no Accounts.';

$lang['Connectreseller.manage.module_groups_title'] = 'Groups';
$lang['Connectreseller.manage.module_groups_heading.name'] = 'Name';
$lang['Connectreseller.manage.module_groups_heading.module_rows'] = 'Accounts';
$lang['Connectreseller.manage.module_groups_heading.options'] = 'Options';

$lang['Connectreseller.manage.module_groups.edit'] = 'Edit';
$lang['Connectreseller.manage.module_groups.delete'] = 'Delete';
$lang['Connectreseller.manage.module_groups.confirm_delete'] = 'Are you sure you want to delete this Account';

$lang['Connectreseller.manage.module_groups.no_results'] = 'There is no Account Group';


// Add row
$lang['Connectreseller.add_row.box_title'] = 'Connectreseller - Add Account';
$lang['Connectreseller.add_row.add_btn'] = 'Add Account';


// Edit row
$lang['Connectreseller.edit_row.box_title'] = 'Connectreseller - Edit Account';
$lang['Connectreseller.edit_row.edit_btn'] = 'Update Account';


// Row meta
$lang['Connectreseller.row_meta.reseller_name'] = 'Reseller Name';
$lang['Connectreseller.row_meta.api_key'] = 'API Key';


// Errors
$lang['Connectreseller.!error.api_key.valid'] = 'Invalid API Key.';
$lang['Connectreseller.!error.module_row.missing'] = 'An internal error occurred. The module row is unavailable.';
$lang['Connectreseller.!error.domain.valid'] = 'Invalid Domain.';
$lang['Connectreseller.!error.ns.count'] = 'At least two Name Servers must be provided.';
$lang['Connectreseller.!error.ns.valid'] = 'One or more Name Servers are invalid.';


// Service Fields
$lang['Connectreseller.service_fields.domain'] = 'Domain';


// Package Fields
$lang['Connectreseller.package_fields.epp_code'] = 'EPP Code';

$lang['Connectreseller.package_field.tooltip.epp_code'] = 'Whether to allow users to request an EPP Code through the Blesta service interface.';
$lang['Connectreseller.package_fields.tld_options'] = 'TLDs';
$lang['Connectreseller.package_fields.ns'] = 'Name server %1$s';


// Domain fields
$lang['Connectreseller.domain.Websitename'] = 'Domain';
$lang['Connectreseller.transfer.Authcode'] = 'EPP Code';


// WHOIS client tab
$lang['Connectreseller.tab_client_whois'] = 'WHOIS';
$lang['Connectreseller.tab_client_whois.section_registrant'] = 'Registrant';
$lang['Connectreseller.tab_client_whois.section_admin'] = 'Administrator';
$lang['Connectreseller.tab_client_whois.section_technical'] = 'Technical';
$lang['Connectreseller.tab_client_whois.section_billing'] = 'Billing';
$lang['Connectreseller.tab_client_whois.field_submit'] = 'Update';


// Name Servers client tab
$lang['Connectreseller.tab_client_nameservers'] = 'Name Servers';
$lang['Connectreseller.tab_client_nameservers.field_submit'] = 'Update';


// DNS client tab
$lang['Connectreseller.tab_client_dns'] = 'DNS';

$lang['Connectreseller.tab_client_dns.title'] = 'DNS Records';
$lang['Connectreseller.tab_client_dns.title_list'] = 'Current DNS Records';
$lang['Connectreseller.tab_client_dns.title_add'] = 'Add a DNS Record';
$lang['Connectreseller.tab_client_dns.field_delete'] = 'Delete Record(s)';
$lang['Connectreseller.tab_client_dns.field_add'] = 'Add Record';

$lang['Connectreseller.tab_client_dns.record_type'] = 'Type';
$lang['Connectreseller.tab_client_dns.host'] = 'Host';
$lang['Connectreseller.tab_client_dns.value'] = 'Value';
$lang['Connectreseller.tab_client_dns.ttl'] = 'TTL';
$lang['Connectreseller.tab_client_dns.field_delete'] = 'Delete Record(s)';

$lang['Connectreseller.tab_client_dns.record_type'] = 'Record Type';
$lang['Connectreseller.tab_client_dns.record_type.a_record'] = 'A Record';
$lang['Connectreseller.tab_client_dns.record_type.aaaa_record'] = 'AAAA Record';
$lang['Connectreseller.tab_client_dns.record_type.cname_record'] = 'CNAME Record';
$lang['Connectreseller.tab_client_dns.record_type.mx_record'] = 'MX Record';
$lang['Connectreseller.tab_client_dns.record_type.txt_record'] = 'TXT Record';


// URL Forwarding client tab
$lang['Connectreseller.tab_client_urlforwarding'] = 'URL Forwarding';
$lang['Connectreseller.tab_client_urlforwarding.heading_current_rules'] = 'Current Rules';
$lang['Connectreseller.tab_client_urlforwarding.heading_add_rule'] = 'Add Rule';
$lang['Connectreseller.tab_client_urlforwarding.heading_source'] = 'Source';
$lang['Connectreseller.tab_client_urlforwarding.heading_destination'] = 'Destination';
$lang['Connectreseller.tab_client_urlforwarding.heading_options'] = 'Options';
$lang['Connectreseller.tab_client_urlforwarding.option_delete'] = 'Delete';
$lang['Connectreseller.tab_client_urlforwarding.text_no_forwarding_rules'] = 'There are no URL forwarding rules for this domain.';
$lang['Connectreseller.tab_client_urlforwarding.field_destination'] = 'Destination';
$lang['Connectreseller.tab_client_urlforwarding.field_submit'] = 'Add Rule';


// Settings client tab
$lang['Connectreseller.tab_client_settings'] = 'Settings';
$lang['Connectreseller.tab_client_settings.heading_settings'] = 'Settings';
$lang['Connectreseller.tab_client_settings.heading_auth_code'] = 'Authorization Code';
$lang['Connectreseller.tab_client_settings.text_auth_code'] = 'Use this authorization code to transfer your domain to another provider.';
$lang['Connectreseller.tab_client_settings.field_registrar_lock'] = 'Registrar Lock';
$lang['Connectreseller.tab_client_settings.field_registrar_lock_yes'] = 'Set the registrar lock. Recommended to prevent unauthorized transfer.';
$lang['Connectreseller.tab_client_settings.field_registrar_lock_no'] = 'Release the registrar lock so the domain can be transferred.';
$lang['Connectreseller.tab_client_settings.field_whois_privacy'] = 'WHOIS Privacy';
$lang['Connectreseller.tab_client_settings.field_whois_privacy_state_yes'] = 'Enabled';
$lang['Connectreseller.tab_client_settings.field_whois_privacy_state_no'] = 'Disabled';
$lang['Connectreseller.tab_client_settings.field_epp_code'] = 'EPP Code';
$lang['Connectreseller.tab_client_settings.field_submit'] = 'Update Settings';


// WHOIS tab
$lang['Connectreseller.tab_whois'] = 'WHOIS';
$lang['Connectreseller.tab_whois.section_registrant'] = 'Registrant';
$lang['Connectreseller.tab_whois.section_admin'] = 'Administrator';
$lang['Connectreseller.tab_whois.section_technical'] = 'Technical';
$lang['Connectreseller.tab_whois.section_billing'] = 'Billing';
$lang['Connectreseller.tab_whois.field_submit'] = 'Update';


// Name Servers tab
$lang['Connectreseller.tab_nameservers'] = 'Name Servers';
$lang['Connectreseller.tab_nameservers.field_submit'] = 'Update';


// DNS tab
$lang['Connectreseller.tab_dns'] = 'DNS';

$lang['Connectreseller.tab_dns.title'] = 'DNS Records';
$lang['Connectreseller.tab_dns.title_list'] = 'Current DNS Records';
$lang['Connectreseller.tab_dns.title_add'] = 'Add a DNS Record';
$lang['Connectreseller.tab_dns.field_delete'] = 'Delete Record(s)';
$lang['Connectreseller.tab_dns.field_add'] = 'Add Record';

$lang['Connectreseller.tab_dns.record_type'] = 'Type';
$lang['Connectreseller.tab_dns.host'] = 'Host';
$lang['Connectreseller.tab_dns.value'] = 'Value';
$lang['Connectreseller.tab_dns.ttl'] = 'TTL';
$lang['Connectreseller.tab_dns.field_delete'] = 'Delete Record(s)';

$lang['Connectreseller.tab_dns.record_type'] = 'Record Type';
$lang['Connectreseller.tab_dns.record_type.a_record'] = 'A Record';
$lang['Connectreseller.tab_dns.record_type.aaaa_record'] = 'AAAA Record';
$lang['Connectreseller.tab_dns.record_type.cname_record'] = 'CNAME Record';
$lang['Connectreseller.tab_dns.record_type.mx_record'] = 'MX Record';
$lang['Connectreseller.tab_dns.record_type.txt_record'] = 'TXT Record';


// URL Forwarding tab
$lang['Connectreseller.tab_urlforwarding'] = 'URL Forwarding';
$lang['Connectreseller.tab_urlforwarding.heading_current_rules'] = 'Current Rules';
$lang['Connectreseller.tab_urlforwarding.heading_add_rule'] = 'Add Rule';
$lang['Connectreseller.tab_urlforwarding.heading_source'] = 'Source';
$lang['Connectreseller.tab_urlforwarding.heading_destination'] = 'Destination';
$lang['Connectreseller.tab_urlforwarding.heading_options'] = 'Options';
$lang['Connectreseller.tab_urlforwarding.option_delete'] = 'Delete';
$lang['Connectreseller.tab_urlforwarding.text_no_forwarding_rules'] = 'There are no URL forwarding rules for this domain.';
$lang['Connectreseller.tab_urlforwarding.field_destination'] = 'Destination';
$lang['Connectreseller.tab_urlforwarding.field_submit'] = 'Add Rule';


// Settings tab
$lang['Connectreseller.tab_settings'] = 'Settings';
$lang['Connectreseller.tab_settings.heading_settings'] = 'Settings';
$lang['Connectreseller.tab_settings.heading_auth_code'] = 'Authorization Code';
$lang['Connectreseller.tab_settings.text_auth_code'] = 'Use this authorization code to transfer your domain to another provider.';
$lang['Connectreseller.tab_settings.field_registrar_lock'] = 'Registrar Lock';
$lang['Connectreseller.tab_settings.field_registrar_lock_yes'] = 'Set the registrar lock. Recommended to prevent unauthorized transfer.';
$lang['Connectreseller.tab_settings.field_registrar_lock_no'] = 'Release the registrar lock so the domain can be transferred.';
$lang['Connectreseller.tab_settings.field_whois_privacy'] = 'WHOIS Privacy';
$lang['Connectreseller.tab_settings.field_whois_privacy_state_yes'] = 'Enabled';
$lang['Connectreseller.tab_settings.field_whois_privacy_state_no'] = 'Disabled';
$lang['Connectreseller.tab_settings.field_epp_code'] = 'EPP Code';
$lang['Connectreseller.tab_settings.field_submit'] = 'Update Settings';


// Name Servers fields
$lang['Connectreseller.nameserver.ns1'] = 'Name Server 1';
$lang['Connectreseller.nameserver.ns2'] = 'Name Server 2';
$lang['Connectreseller.nameserver.ns3'] = 'Name Server 3';
$lang['Connectreseller.nameserver.ns4'] = 'Name Server 4';


// WHOIS fields
$lang['Connectreseller.whois.Name'] = 'Full Name';
$lang['Connectreseller.whois.EmailAddress'] = 'Email Address';
$lang['Connectreseller.whois.Address'] = 'Address';
$lang['Connectreseller.whois.City'] = 'City';
$lang['Connectreseller.whois.StateName'] = 'State';
$lang['Connectreseller.whois.CountryName'] = 'Country';
$lang['Connectreseller.whois.Zip'] = 'Zip Code';
$lang['Connectreseller.whois.PhoneNo'] = 'Phone';

// .US Contact Fields
$lang['Connectreseller.domain_fields.category'] = 'Registrant Type';
$lang['Connectreseller.domain_fields.category.c11'] = 'US citizen';
$lang['Connectreseller.domain_fields.category.c12'] = 'Permanent resident of the US';
$lang['Connectreseller.domain_fields.category.c21'] = 'US entity or organization';
$lang['Connectreseller.domain_fields.category.c31'] = 'Foreign organization';
$lang['Connectreseller.domain_fields.category.c32'] = 'Foreign organization with an office in the US';
$lang['Connectreseller.domain_fields.purpose'] = 'Purpose';
$lang['Connectreseller.domain_fields.purpose.p1'] = 'Business';
$lang['Connectreseller.domain_fields.purpose.p2'] = 'Non-profit';
$lang['Connectreseller.domain_fields.purpose.p3'] = 'Personal';
$lang['Connectreseller.domain_fields.purpose.p4'] = 'Educational';
$lang['Connectreseller.domain_fields.purpose.p5'] = 'Governmental';

==> blesta-5.8.0-5.8.3.zip: blesta/components/modules/connectreseller/language/en_us/connectreseller.php <==
<?php
/**
 * en_us language for the Connectreseller module.
 */
// Basics
$lang['Connectreseller.name'] = 'ConnectReseller';
$lang['Connectreseller.description'] = 'ConnectReseller is one of the largest Registrars that has created a of set completely private labeled programs for domainers.';
$lang['Connectreseller.module_row'] = 'Account';
$lang['Connectreseller.module_row_plural'] = 'Accounts';
$lang['Connectreseller.module_group'] = 'Account Group';


// Module management
$lang['Connectreseller.add_module_row'] = 'Add Account';
$lang['Connectreseller.add_module_group'] = 'Add Account Group';
$lang['Connectreseller.manage.module_rows_title'] = 'Accounts';

$lang['Connectreseller.manage.module_rows_heading.reseller_name'] = 'Reseller Name';
$lang['Connectreseller.manage.module_rows_heading.api_key'] = 'API Key';
$lang['Connectreseller.manage.module_rows_heading.options'] = 'Options';
$lang['Connectreseller.manage.module_rows.edit'] = 'Edit';
$lang['Connectreseller.manage.module_rows.delete'] = 'Delete';
$lang['Connectreseller.manage.module_rows.confirm_delete'] = 'Are you sure you want to delete this Account';

$lang['Connectreseller.manage.module_rows_no_results'] = 'There are no Accounts.';

$lang['Connectreseller.manage.module_groups_title'] = 'Groups';
$lang['Connectreseller.manage.module_groups_heading.name'] = 'Name';
$lang['Connectreseller.manage.module_groups_heading.module_rows'] = 'Accounts';
$lang['Connectreseller.manage.module_groups_heading.options'] = 'Options';

$lang['Connectreseller.manage.module_groups.edit'] = 'Edit';
$lang['Connectreseller.manage.module_groups.delete'] = 'Delete';
$lang['Connectreseller.manage.module_groups.confirm_delete'] = 'Are you sure you want to delete this Account';

$lang['Connectreseller.manage.module_groups.no_results'] = 'There is no Account Group';

$lang['Connectreseller.order_options.first'] = 'First Non-full Server';
$lang['Connectreseller.order_options.roundrobin'] = 'Evenly Distribute Among Servers';


// Add row
$lang['Connectreseller.add_row.box_title'] = 'Connectreseller - Add Account';
$lang['Connectreseller.add_row.add_btn'] = 'Add Account';


// Edit row
$lang['Connectreseller.edit_row.box_title'] = 'Connectreseller - Edit Account';
$lang['Connectreseller.edit_row.edit_btn'] = 'Update Account';


// Row meta
$lang['Connectreseller.row_meta.reseller_name'] = 'Reseller Name';
$lang['Connectreseller.row_meta.api_key'] = 'API Key';


// Errors
$lang['Connectreseller.!error.api_key.valid'] = 'Invalid API Key.';
$lang['Connectreseller.!error.module_row.missing'] = 'An internal error occurred. The module row is unavailable.';
$lang['Connectreseller.!error.domain.valid'] = 'Invalid Domain.';
$lang['Connectreseller.!error.ns.count'] = 'At least two Name Servers must be provided.';
$lang['Connectreseller.!error.ns.valid'] = 'One or more Name Servers are invalid.';


// Service Fields
$lang['Connectreseller.service_fields.domain'] = 'Domain';


// Package Fields
$lang['Connectreseller.package_fields.epp_code'] = 'EPP Code';

$lang['Connectreseller.package_field.tooltip.epp_code'] = 'Whether to allow users to request an EPP Code through the Blesta service interface.';
$lang['Connectreseller.package_fields.tld_options'] = 'TLDs';
$lang['Connectreseller.package_fields.ns'] = 'Name server %1$s';


// Domain fields
$lang['Connectreseller.domain.Websitename'] = 'Domain';
$lang['Connectreseller.transfer.Authcode'] = 'EPP Code';


// WHOIS client tab
$lang['Connectreseller.tab_client_whois'] = 'WHOIS';
$lang['Connectreseller.tab_client_whois.section_registrant'] = 'Registrant';
$lang['Connectreseller.tab_client_whois.section_admin'] = 'Administrator';
$lang['Connectreseller.tab_client_whois.section_technical'] = 'Technical';
$lang['Connectreseller.tab_client_whois.section_billing'] = 'Billing';
$lang['Connectreseller.tab_client_whois.field_submit'] = 'Update';


// Name Servers client tab
$lang['Connectreseller.tab_client_nameservers.title_list'] = 'Nameservers';
$lang['Connectreseller.tab_client_nameservers'] = 'Name Servers';
$lang['Connectreseller.tab_client_nameservers.field_submit'] = 'Update';


// DNS client tab
$lang['Connectreseller.tab_client_dns'] = 'DNS';

$lang['Connectreseller.tab_client_dns.title'] = 'DNS Records';
$lang['Connectreseller.tab_client_dns.title_list'] = 'Current DNS Records';
$lang['Connectreseller.tab_client_dns.title_add'] = 'Add a DNS Record';
$lang['Connectreseller.tab_client_dns.field_delete'] = 'Delete Record(s)';
$lang['Connectreseller.tab_client_dns.field_add'] = 'Add Record';

$lang['Connectreseller.tab_client_dns.record_type'] = 'Type';
$lang['Connectreseller.tab_client_dns.host'] = 'Host';
$lang['Connectreseller.tab_client_dns.value'] = 'Value';
$lang['Connectreseller.tab_client_dns.ttl'] = 'TTL';
$lang['Connectreseller.tab_client_dns.field_delete'] = 'Delete Record(s)';

$lang['Connectreseller.tab_client_dns.record_type'] = 'Record Type';
$lang['Connectreseller.tab_client_dns.record_type.a_record'] = 'A Record';
$lang['Connectreseller.tab_client_dns.record_type.aaaa_record'] = 'AAAA Record';
$lang['Connectreseller.tab_client_dns.record_type.cname_record'] = 'CNAME Record';
$lang['Connectreseller.tab_client_dns.record_type.mx_record'] = 'MX Record';
$lang['Connectreseller.tab_client_dns.record_type.txt_record'] = 'TXT Record';


// URL Forwarding client tab
$lang['Connectreseller.tab_client_urlforwarding'] = 'URL Forwarding';
$lang['Connectreseller.tab_client_urlforwarding.heading_current_rules'] = 'Current Rule';
$lang['Connectreseller.tab_client_urlforwarding.heading_add_rule'] = 'Update Rule';
$lang['Connectreseller.tab_client_urlforwarding.heading_source'] = 'Source';
$lang['Connectreseller.tab_client_urlforwarding.heading_destination'] = 'Destination';
$lang['Connectreseller.tab_client_urlforwarding.heading_options'] = 'Options';
$lang['Connectreseller.tab_client_urlforwarding.option_delete'] = 'Delete';
$lang['Connectreseller.tab_client_urlforwarding.text_no_forwarding_rules'] = 'There is no URL forwarding rule for this domain.';
$lang['Connectreseller.tab_client_urlforwarding.field_destination'] = 'Destination';
$lang['Connectreseller.tab_client_urlforwarding.field_submit'] = 'Update Rule';


// Settings client tab
$lang['Connectreseller.tab_client_settings'] = 'Settings';
$lang['Connectreseller.tab_client_settings.heading_settings'] = 'Settings';
$lang['Connectreseller.tab_client_settings.heading_auth_code'] = 'Authorization Code';
$lang['Connectreseller.tab_client_settings.text_auth_code'] = 'Use this authorization code to transfer your domain to another provider.';
$lang['Connectreseller.tab_client_settings.field_registrar_lock'] = 'Registrar Lock';
$lang['Connectreseller.tab_client_settings.field_registrar_lock_yes'] = 'Set the registrar lock. Recommended to prevent unauthorized transfer.';
$lang['Connectreseller.tab_client_settings.field_registrar_lock_no'] = 'Release the registrar lock so the domain can be transferred.';
$lang['Connectreseller.tab_client_settings.field_whois_privacy'] = 'WHOIS Privacy';
$lang['Connectreseller.tab_client_settings.field_whois_privacy_state_yes'] = 'Enabled';
$lang['Connectreseller.tab_client_settings.field_whois_privacy_state_no'] = 'Disabled';
$lang['Connectreseller.tab_client_settings.field_epp_code'] = 'EPP Code';
$lang['Connectreseller.tab_client_settings.field_submit'] = 'Update Settings';


// WHOIS tab
$lang['Connectreseller.tab_whois'] = 'WHOIS';
$lang['Connectreseller.tab_whois.section_registrant'] = 'Registrant';
$lang['Connectreseller.tab_whois.section_admin'] = 'Administrator';
$lang['Connectreseller.tab_whois.section_technical'] = 'Technical';
$lang['Connectreseller.tab_whois.section_billing'] = 'Billing';
$lang['Connectreseller.tab_whois.field_submit'] = 'Update';


// Name Servers tab
$lang['Connectreseller.tab_nameservers.title_list'] = 'Nameservers';
$lang['Connectreseller.tab_nameservers'] = 'Name Servers';
$lang['Connectreseller.tab_nameservers.field_submit'] = 'Update';


// DNS tab
$lang['Connectreseller.tab_dns'] = 'DNS';

$lang['Connectreseller.tab_dns.title'] = 'DNS Records';
$lang['Connectreseller.tab_dns.title_list'] = 'Current DNS Records';
$lang['Connectreseller.tab_dns.title_add'] = 'Add a DNS Record';
$lang['Connectreseller.tab_dns.field_delete'] = 'Delete Record(s)';
$lang['Connectreseller.tab_dns.field_add'] = 'Add Record';

$lang['Connectreseller.tab_dns.record_type'] = 'Type';
$lang['Connectreseller.tab_dns.host'] = 'Host';
$lang['Connectreseller.tab_dns.value'] = 'Value';
$lang['Connectreseller.tab_dns.ttl'] = 'TTL';
$lang['Connectreseller.tab_dns.field_delete'] = 'Delete Record(s)';

$lang['Connectreseller.tab_dns.record_type'] = 'Record Type';
$lang['Connectreseller.tab_dns.record_type.a_record'] = 'A Record';
$lang['Connectreseller.tab_dns.record_type.aaaa_record'] = 'AAAA Record';
$lang['Connectreseller.tab_dns.record_type.cname_record'] = 'CNAME Record';
$lang['Connectreseller.tab_dns.record_type.mx_record'] = 'MX Record';
$lang['Connectreseller.tab_dns.record_type.txt_record'] = 'TXT Record';


// URL Forwarding tab
$lang['Connectreseller.tab_urlforwarding'] = 'URL Forwarding';
$lang['Connectreseller.tab_urlforwarding.heading_current_rules'] = 'Current Rule';
$lang['Connectreseller.tab_urlforwarding.heading_add_rule'] = 'Update Rule';
$lang['Connectreseller.tab_urlforwarding.heading_source'] = 'Source';
$lang['Connectreseller.tab_urlforwarding.heading_destination'] = 'Destination';
$lang['Connectreseller.tab_urlforwarding.heading_options'] = 'Options';
$lang['Connectreseller.tab_urlforwarding.option_delete'] = 'Delete';
$lang['Connectreseller.tab_urlforwarding.text_no_forwarding_rules'] = 'There is no URL forwarding rule for this domain.';
$lang['Connectreseller.tab_urlforwarding.field_destination'] = 'Destination';
$lang['Connectreseller.tab_urlforwarding.field_submit'] = 'Update Rule';


// Settings tab
$lang['Connectreseller.tab_settings'] = 'Settings';
$lang['Connectreseller.tab_settings.heading_settings'] = 'Settings';
$lang['Connectreseller.tab_settings.heading_auth_code'] = 'Authorization Code';
$lang['Connectreseller.tab_settings.text_auth_code'] = 'Use this authorization code to transfer your domain to another provider.';
$lang['Connectreseller.tab_settings.field_registrar_lock'] = 'Registrar Lock';
$lang['Connectreseller.tab_settings.field_registrar_lock_yes'] = 'Set the registrar lock. Recommended to prevent unauthorized transfer.';
$lang['Connectreseller.tab_settings.field_registrar_lock_no'] = 'Release the registrar lock so the domain can be transferred.';
$lang['Connectreseller.tab_settings.field_whois_privacy'] = 'WHOIS Privacy';
$lang['Connectreseller.tab_settings.field_whois_privacy_state_yes'] = 'Enabled';
$lang['Connectreseller.tab_settings.field_whois_privacy_state_no'] = 'Disabled';
$lang['Connectreseller.tab_settings.field_epp_code'] = 'EPP Code';
$lang['Connectreseller.tab_settings.field_submit'] = 'Update Settings';


// Name Servers fields
$lang['Connectreseller.nameserver.ns1'] = 'Name Server 1';
$lang['Connectreseller.nameserver.ns2'] = 'Name Server 2';
$lang['Connectreseller.nameserver.ns3'] = 'Name Server 3';
$lang['Connectreseller.nameserver.ns4'] = 'Name Server 4';


// WHOIS fields
$lang['Connectreseller.whois.Name'] = 'Full Name';
$lang['Connectreseller.whois.EmailAddress'] = 'Email Address';
$lang['Connectreseller.whois.Address'] = 'Address';
$lang['Connectreseller.whois.City'] = 'City';
$lang['Connectreseller.whois.StateName'] = 'State';
$lang['Connectreseller.whois.CountryName'] = 'Country';
$lang['Connectreseller.whois.Zip'] = 'Zip Code';
$lang['Connectreseller.whois.PhoneNo'] = 'Phone';

// .US Contact Fields
$lang['Connectreseller.domain_fields.category'] = 'Registrant Type';
$lang['Connectreseller.domain_fields.category.c11'] = 'US citizen';
$lang['Connectreseller.domain_fields.category.c12'] = 'Permanent resident of the US';
$lang['Connectreseller.domain_fields.category.c21'] = 'US entity or organization';
$lang['Connectreseller.domain_fields.category.c31'] = 'Foreign organization';
$lang['Connectreseller.domain_fields.category.c32'] = 'Foreign organization with an office in the US';
$lang['Connectreseller.domain_fields.purpose'] = 'Purpose';
$lang['Connectreseller.domain_fields.purpose.p1'] = 'Business';
$lang['Connectreseller.domain_fields.purpose.p2'] = 'Non-profit';
$lang['Connectreseller.domain_fields.purpose.p3'] = 'Personal';
$lang['Connectreseller.domain_fields.purpose.p4'] = 'Educational';
$lang['Connectreseller.domain_fields.purpose.p5'] = 'Governmental';
